import QtQuick 1.1
import com.nokia.meego 1.0
import org.maliit.japanese 1.0

PageStackWindow {


    initialPage  {

        Page {
            id: root
            anchors.fill: parent

            Settings {
                id: settings

            }

            property int r: 0
            property int g: 0
            property int b: 0

            //property color keyboardColor: settings.color;

            function setColor(r, g, b) {
                root.r = r;
                root.g = g;
                root.b = b;
                settings.color =  Qt.rgba(r/255.0,  g/255.0, b/255.0, 1);
            }

            function parseColor(i) {
                var c = parseInt(('' + settings.color).substring(i*2+1, i*2+3), 16);
                if (i==0) root.r = c;
                if (i==1) root.g = c;
                if (i==2) root.b = c;
                return c;
            }

            Component.onCompleted: {

                console.debug("source before switch:" , settings.source);
                switch (settings.source) {
                case "":
                    sourceSelectionDialog.selectedIndex = 0;
                    break;
                case "1.png":
                    sourceSelectionDialog.selectedIndex = 1;
                    break;
                case "2.png":
                    sourceSelectionDialog.selectedIndex = 2;
                    break;
                case "3.png":
                    sourceSelectionDialog.selectedIndex = 3;
                    break;
                default:
                    {
                        imageUrl.text = settings.source;
                        sourceSelectionDialog.selectedIndex = 4;
                        console.debug("url:", imageUrl.text);
                    }
                    break;
                }

                console.debug("vol:", settings.volume);
                volumeSlider.value = settings.volume;
                console.debug("volumeSlider:", volumeSlider.value);

                console.debug("settings.color:", settings.color);
                redSlider.value = root.r = parseColor(0);
                greenSlider.value = root.g = parseColor(1);
                blueSlider.value = root.b = parseColor(2);

                burstSwitch.checked = settings.burst;
            }

            LayoutItem {
                anchors.fill: parent

                Column {
                    id: column
                    spacing: 10

                    // Particles source image setting
                    Item {
                        width: root.width-20
                        height: 40


                        Label {
                            id: particlesImage
                            x: 0
                            anchors.verticalCenter: parent.verticalCenter
                            text: "Particles image: "
                        }

                        Label {
                            anchors.left: particlesImage.right
                            anchors.verticalCenter: parent.verticalCenter
                            text: sourceSelectionDialog.model.get(
                                sourceSelectionDialog.selectedIndex).name
                        }

                        Button {
                            anchors.right: parent.right
                            width: 64
                            iconSource: "image://theme/icon-m-common-combobox-arrow"
                            onClicked: {
                                sourceSelectionDialog.open();
                            }
                        }

                        SelectionDialog {
                            id: sourceSelectionDialog
                            selectedIndex: 0

                            model: ListModel {
                                ListElement { name: "None" }
                                ListElement { name: "1.png" }
                                ListElement { name: "2.png" }
                                ListElement { name: "3.png" }
                                ListElement { name: "Other" }
                            }

                            onSelectedIndexChanged: {
                                var str = sourceSelectionDialog.model.get(
                                    sourceSelectionDialog.selectedIndex).name;
                                if (str == "None")
                                    str = "";
                                else if (str == "Other")
                                    str = imageUrl.text;
                                settings.source = str;
                            }
                        }
                    }

                    Item {
                        width: root.width-20
                        height: 40

                        Label {
                            id: imageUrlLabel
                            x: 20
                            anchors.verticalCenter: parent.verticalCenter
                            text: "image URL: "
                            enabled: sourceSelectionDialog.selectedIndex == 4 ? true : false
                        }

                        TextInput {
                            id: imageUrl
                            anchors.left: imageUrlLabel.right
                            anchors.right: parent.right
                            anchors.verticalCenter: parent.verticalCenter
                            enabled: sourceSelectionDialog.selectedIndex == 4 ? true : false
                            font.pixelSize: imageUrlLabel.font.pixelSize

                            onAccepted: { settings.source = imageUrl.text; }
                        }

                    }

                    Item {
                        width: root.width-20
                        height: 40

                        Label {
                            id: particlesVolume
                            x: 0
                            anchors.verticalCenter: parent.verticalCenter
                            text: "Particles Volume: "
                        }

                        Label {
                            anchors.left: particlesVolume.right
                            text: volumeSlider.value
                            anchors.verticalCenter: parent.verticalCenter
                            width: 50
                        }
                    }

                    Item {
                        width: root.width-20
                        height: 40

                        Slider {
                            id: volumeSlider
                            anchors.left: parent.left
                            anchors.right: parent.right
                            anchors.verticalCenter: parent.verticalCenter
                            minimumValue: 0
                            maximumValue: 100
                            stepSize: 1

                            onValueChanged: {
                                var newVal = volumeSlider.value;
                                if (settings.volume != newVal)
                                    settings.volume = newVal;
                            }
                        }
                    }

                    Item {
                        width: root.width-20
                        height: 40

                        Label {
                            x: 0
                            anchors.verticalCenter: parent.verticalCenter
                            text: "Particles bursts at last: "
                        }

                        Switch {
                            id: burstSwitch
                            anchors.right: parent.right
                            anchors.verticalCenter: parent.verticalCenter
                            onCheckedChanged: {
                                settings.burst = burstSwitch.checked;
                            }
                        }
                    }

                    Item {
                        width: root.width-20
                        height: 40

                        Label {
                            x:0
                            anchors.verticalCenter: parent.verticalCenter
                            text: "Keyboard color: "
                        }
                    }

                    Item {
                        width: root.width-20
                        height: 40

                        Label {
                            id: redLabel
                            x: 20
                            anchors.verticalCenter: parent.verticalCenter
                            text: "R"
                        }

                        Slider {
                            id: redSlider
                            anchors.left: redLabel.right
                            anchors.right: parent.right
                            anchors.verticalCenter: parent.verticalCenter
                            minimumValue: 0
                            maximumValue: 255
                            stepSize: 1

                            onValueChanged: {
                                var newVal = redSlider.value;
                                if (root.r != newVal) {
                                    root.setColor(newVal, root.g, root.b);
                                }
                            }
                        }
                    }
                    Item {
                        width: root.width-20
                        height: 40

                        Label {
                            id: greenLabel
                            x: 20
                            anchors.verticalCenter: parent.verticalCenter
                            text: "G"
                        }

                        Slider {
                            id: greenSlider
                            anchors.left: greenLabel.right
                            anchors.right: parent.right
                            anchors.verticalCenter: parent.verticalCenter
                            minimumValue: 0
                            maximumValue: 255
                            stepSize: 1

                            onValueChanged: {
                                var newVal = greenSlider.value;
                                if (root.g != newVal) {
                                    root.setColor(root.r, newVal, root.b);
                                }
                            }
                        }
                    }
                    Item {
                        width: root.width-20
                        height: 40

                        Label {
                            id: blueLabel
                            x: 20
                            anchors.verticalCenter: parent.verticalCenter
                            text: "B"
                        }

                        Slider {
                            id: blueSlider
                            anchors.left: blueLabel.right
                            anchors.right: parent.right
                            anchors.verticalCenter: parent.verticalCenter
                            minimumValue: 0
                            maximumValue: 255
                            stepSize: 1

                            onValueChanged: {
                                var newVal = blueSlider.value;
                                if (root.b != newVal) {
                                    root.setColor(root.r, root.g, newVal);
                                }
                            }
                        }
                    }

                    Rectangle {
                        id: colorSample
                        x: 20
                        width: root.width-40
                        height: 20
                        //color: root.keyboardColor
                        color: settings.color
                    }

                    TextArea  {
                        width: root.width
                        height: 100

                    }
                }
            }
        }
    }

    showStatusBar: true
    showToolBar: false
}
